@@ -12,60 +12,60 @@ sub get {
 				'exit-unsaved' => 'Kephra::App::exit_unsaved()',
 			},
 			file => {
-				'new' => 'Kephra::File::new()',
-				'open' => 'Kephra::File::open()',
+				new => 'Kephra::File::new()',
+				open => 'Kephra::File::open()',
 				'open-dir' => 'Kephra::File::open_all_of_dir()',
-				'reload' => 'Kephra::File::reload_current()',
+				reload => 'Kephra::File::reload_current()',
 				'reload-all' => 'Kephra::File::reload_all()',
-				'insert' => 'Kephra::File::insert()',
+				insert => 'Kephra::File::insert()',
 				save => {
-					'current' => 'Kephra::File::save_current()',
-					'all' => 'Kephra::File::save_all()',
-					'as' => 'Kephra::File::save_as()',
+					current => 'Kephra::File::save_current()',
+					all => 'Kephra::File::save_all()',
+					as => 'Kephra::File::save_as()',
 					'copy-as' => 'Kephra::File::save_copy_as()',
 				},
-				'rename' => 'Kephra::File::rename()',
-				'print' => 'Kephra::File::print()',
+				rename => 'Kephra::File::rename()',
+				print => 'Kephra::File::print()',
 				close => {
-					'current' => 'Kephra::File::close()',
-					'all' => 'Kephra::File::close_all()',
-					'other' => 'Kephra::File::close_other()',
-					'unsaved' => 'Kephra::File::close_unsaved()',
+					current => 'Kephra::File::close()',
+					all => 'Kephra::File::close_all()',
+					other => 'Kephra::File::close_other()',
+					unsaved => 'Kephra::File::close_unsaved()',
 					'all-unsaved' => 'Kephra::File::close_all_unsaved()',
 					'other-unsaved' => 'Kephra::File::close_other_unsaved()',
 				},
 				session => {
-					'open' => 'Kephra::File::Session::open_file()',
-					'add' => 'Kephra::File::Session::add()',
-					'save' => 'Kephra::File::Session::save_as()',
-					'import' => 'Kephra::File::Session::import_scite()',
-					'export' => 'Kephra::File::Session::export_scite()',
+					open => 'Kephra::File::Session::open_file()',
+					add => 'Kephra::File::Session::add()',
+					save => 'Kephra::File::Session::save_as()',
+					import => 'Kephra::File::Session::import_scite()',
+					export => 'Kephra::File::Session::export_scite()',
 					'backup-open' => 'Kephra::File::Session::load_backup()',
 					'backup-save' => 'Kephra::File::Session::save_backup()',
 				},
 			},
 			edit => {
 				changes => {
-					'undo' => 'Kephra::Edit::History::undo()',
-					'redo' => 'Kephra::Edit::History::redo()',
+					undo => 'Kephra::Edit::History::undo()',
+					redo => 'Kephra::Edit::History::redo()',
 					'undo-several' => 'Kephra::Edit::History::undo_several()',
 					'redo-several' => 'Kephra::Edit::History::redo_several()',
 					'goto-begin' => 'Kephra::Edit::History::undo_begin()',
 					'goto-end' => 'Kephra::Edit::History::redo_end()',
-					'delete' => 'Kephra::Edit::History::clear_history()',
+					delete => 'Kephra::Edit::History::clear_history()',
 				},
-				'cut' => 'Kephra::Edit::cut()',
-				'copy' => 'Kephra::Edit::copy()',
-				'paste' => 'Kephra::Edit::paste()',
-				'replace' => 'Kephra::Edit::replace()',
-				'delete' => 'Kephra::Edit::clear()',
+				cut => 'Kephra::Edit::cut()',
+				copy => 'Kephra::Edit::copy()',
+				paste => 'Kephra::Edit::paste()',
+				replace => 'Kephra::Edit::replace()',
+				delete => 'Kephra::Edit::clear()',
 				'delete-tab' => 'Kephra::Edit::del_back_tab()',
 				line => {
-					'cut' => 'Kephra::Edit::cut_current_line()',
-					'copy' => 'Kephra::Edit::copy_current_line()',
-					'duplicate' => 'Kephra::Edit::double_current_line()',
-					'replace' => 'Kephra::Edit::replace_current_line()',
-					'delete' => 'Kephra::Edit::del_current_line()',
+					cut => 'Kephra::Edit::cut_current_line()',
+					copy => 'Kephra::Edit::copy_current_line()',
+					duplicate => 'Kephra::Edit::double_current_line()',
+					replace => 'Kephra::Edit::replace_current_line()',
+					delete => 'Kephra::Edit::del_current_line()',
 					'delete-left' => 'Kephra::Edit::del_line_left()',
 					'delete-right' => 'Kephra::Edit::del_line_right()',
 					move => {
@@ -77,12 +77,16 @@ sub get {
 				},
 				selection => {
 					convert => {
-						'uppercase' => 'Kephra::Edit::Convert::upper_case()',
-						'lowercase' => 'Kephra::Edit::Convert::lower_case()',
-						'titlecase' => 'Kephra::Edit::Convert::title_case()',
-						'sentencecase' => 'Kephra::Edit::Convert::sentence_case()',
-						'spaces2tabs' => 'Kephra::Edit::Convert::spaces2tabs()',
-						'tabs2spaces' => 'Kephra::Edit::Convert::tabs2spaces()',
+						uppercase => 'Kephra::Edit::Convert::upper_case()',
+						lowercase => 'Kephra::Edit::Convert::lower_case()',
+						titlecase => 'Kephra::Edit::Convert::title_case()',
+						sentencecase => 'Kephra::Edit::Convert::sentence_case()',
+						spaces2tabs => 'Kephra::Edit::Convert::spaces2tabs()',
+						tabs2spaces => 'Kephra::Edit::Convert::tabs2spaces()',
+						spaces2entities => 'Kephra::Edit::Convert::spaces2entities()',
+						entities2spaces => 'Kephra::Edit::Convert::entities2spaces()',
+						chars2entities => 'Kephra::Edit::Convert::chars2entities()',
+						entities2chars => 'Kephra::Edit::Convert::entities2chars()',
 					},
 					comment => {
 						'add-perl' => "Kephra::Edit::Comment::add_block('#')",
@@ -117,10 +121,10 @@ sub get {
 				},
 				document => {
 					convert => {
-						'indent2spaces' => 'Kephra::Document::convert_indent2spaces()',
-						'indent2tabs' => 'Kephra::Document::convert_indent2tabs()',
-						'spaces2tabs' => 'Kephra::Document::convert_spaces2tabs()',
-						'tabs2spaces' => 'Kephra::Document::convert_tabs2spaces()',
+						indent2spaces => 'Kephra::Document::convert_indent2spaces()',
+						indent2tabs => 'Kephra::Document::convert_indent2tabs()',
+						spaces2tabs => 'Kephra::Document::convert_spaces2tabs()',
+						tabs2spaces => 'Kephra::Document::convert_tabs2spaces()',
 					},
 					format => {
 						'del-trailing-whitespace' => 'Kephra::Document::del_trailing_spaces()',
@@ -128,7 +132,7 @@ sub get {
 				},
 			},
 			select => {
-				'document' => 'Kephra::Edit::Select::document()',
+				document => 'Kephra::Edit::Select::document()',
 				'to-block-begin' => 'Kephra::Edit::Select::to_block_begin()',
 				'to-block-end' => 'Kephra::Edit::Select::to_block_end()',
 			},
@@ -144,29 +148,29 @@ sub get {
 					},
 				},
 				range => {
-					'selection' => "Kephra::Edit::Search::set_range('selection')",
-					'document' => "Kephra::Edit::Search::set_range('document')",
+					selection => "Kephra::Edit::Search::set_range('selection')",
+					document => "Kephra::Edit::Search::set_range('document')",
 					'open-docs' => "Kephra::Edit::Search::set_range('open_docs')",
 				},
 			},
 			find => {
-				'prev' => 'Kephra::Edit::Search::find_prev()',
-				'next' => 'Kephra::Edit::Search::find_next()',
-				'first' => 'Kephra::Edit::Search::find_first()',
-				'last' => 'Kephra::Edit::Search::find_last()',
-				'selection' => 'Kephra::Edit::Search::set_selection_as_find_item()',
+				prev => 'Kephra::Edit::Search::find_prev()',
+				next => 'Kephra::Edit::Search::find_next()',
+				first => 'Kephra::Edit::Search::find_first()',
+				last => 'Kephra::Edit::Search::find_last()',
+				selection => 'Kephra::Edit::Search::set_selection_as_find_item()',
 			},
 			replace => {
-				'prev' => 'Kephra::Edit::Search::replace_back()',
-				'next' => 'Kephra::Edit::Search::replace_fore()',
-				'all' => 'Kephra::Edit::Search::replace_all()',
+				prev => 'Kephra::Edit::Search::replace_back()',
+				next => 'Kephra::Edit::Search::replace_fore()',
+				all => 'Kephra::Edit::Search::replace_all()',
 				'with-confirm' => 'Kephra::Edit::Search::replace_confirm()',
-				'selection' => 'Kephra::Edit::Search::set_selection_as_replace_item()',
+				selection => 'Kephra::Edit::Search::set_selection_as_replace_item()',
 			},
 			goto => {
 				block => {
-					'down' => 'Kephra::Edit::Goto::next_block()',
-					'up' => 'Kephra::Edit::Goto::prev_block()',
+					down => 'Kephra::Edit::Goto::next_block()',
+					up => 'Kephra::Edit::Goto::prev_block()',
 				},
 				brace => {
 					down => 'Kephra::Edit::Goto::next_related_brace()',
@@ -205,92 +209,93 @@ sub get {
 				'delete-all' => 'Kephra::Edit::Bookmark::delete_all()',
 			},
 			tool => {
-				note => 'Kephra::Extension::Notepad::note()',
-				'run-document' => 'Kephra::Extension::Output::run()',
-				'stop-document' => 'Kephra::Extension::Output::stop()',
+				note => 'Kephra::Plugin::Notepad::note()',
+				'note-selection' => 'Kephra::Plugin::Notepad::append_selection()',
+				'interpreter-run-document' => 'Kephra::Plugin::Output::run()',
+				'interpreter-stop-document' => 'Kephra::Plugin::Output::stop()',
+				'output-inc' => 'Kephra::Plugin::Output::display_inc()',
 			},
 			document => {
-				'auto-indention' => 'Kephra::Document::switch_autoindention()',
-				'brace-indention' => 'Kephra::Document::switch_braceindention()',
-				'brace-light' => 'Kephra::Document::switch_bracelight()',
+				'auto-indention' => 'Kephra::Document::Property::switch_autoindention()',
+				'brace-indention' => 'Kephra::Document::Property::switch_braceindention()',
 				change => {
 					back => 'Kephra::Document::Change::switch_back()',
 					prev => 'Kephra::Document::Change::tab_left()',
 					next => 'Kephra::Document::Change::tab_right()',
 				},
 				EOL => {
-					'auto' => "Kephra::Document::convert_EOL('auto')",
-					'cr+lf' => "Kephra::Document::convert_EOL('cr+lf')",
-					'cr' => "Kephra::Document::convert_EOL('cr')",
-					'lf' => "Kephra::Document::convert_EOL('lf')",
+					'auto' => "Kephra::Document::Property::convert_EOL('auto')",
+					'cr+lf' => "Kephra::Document::Property::convert_EOL('cr+lf')",
+					cr => "Kephra::Document::Property::convert_EOL('cr')",
+					lf => "Kephra::Document::Property::convert_EOL('lf')",
 				},
 				move => {
 					left => 'Kephra::Document::Change::move_left()',
 					right => 'Kephra::Document::Change::move_right()',
 				},
 				readonly => {
-					'as-attr' => "Kephra::Document::set_readonly('protect')",
-					on => "Kephra::Document::set_readonly('on')",
-					off => "Kephra::Document::set_readonly('off')",
+					'as-attr' => "Kephra::Document::Property::set_readonly('protect')",
+					on => "Kephra::Document::Property::set_readonly('on')",
+					off => "Kephra::Document::Property::set_readonly('off')",
 				},
 				syntaxmode => {
-					auto => "Kephra::Document::SyntaxMode::change_to('auto')",
-					none => "Kephra::Document::SyntaxMode::change_to('none')",
-					ada => "Kephra::Document::SyntaxMode::change_to('ada')",
-					as => "Kephra::Document::SyntaxMode::change_to('as')",
-					asm => "Kephra::Document::SyntaxMode::change_to('asm')",
-					ave => "Kephra::Document::SyntaxMode::change_to('ave')",
-					baan => "Kephra::Document::SyntaxMode::change_to('baan')",
-					batch => "Kephra::Document::SyntaxMode::change_to('batch')",
-					c => "Kephra::Document::SyntaxMode::change_to('cpp')",
-					conf => "Kephra::Document::SyntaxMode::change_to('conf')",
-					context => "Kephra::Document::SyntaxMode::change_to('context')",
-					cs => "Kephra::Document::SyntaxMode::change_to('cs')",
-					css => "Kephra::Document::SyntaxMode::change_to('css')",
-					diff => "Kephra::Document::SyntaxMode::change_to('diff')",
-					eiffel => "Kephra::Document::SyntaxMode::change_to('eiffel')",
-					err => "Kephra::Document::SyntaxMode::change_to('err')",
-					forth => "Kephra::Document::SyntaxMode::change_to('forth')",
-					fortran => "Kephra::Document::SyntaxMode::change_to('fortran')",
-					html => "Kephra::Document::SyntaxMode::change_to('html')",
-					idl => "Kephra::Document::SyntaxMode::change_to('idl')",
-					java => "Kephra::Document::SyntaxMode::change_to('java')",
-					js => "Kephra::Document::SyntaxMode::change_to('js')",
-					latex => "Kephra::Document::SyntaxMode::change_to('latex')",
-					lisp => "Kephra::Document::SyntaxMode::change_to('lisp')",
-					lua => "Kephra::Document::SyntaxMode::change_to('lua')",
-					make => "Kephra::Document::SyntaxMode::change_to('make')",
-					matlab => "Kephra::Document::SyntaxMode::change_to('matlab')",
-					nsis => "Kephra::Document::SyntaxMode::change_to('nsis')",
-					pascal => "Kephra::Document::SyntaxMode::change_to('pascal')",
-					perl => "Kephra::Document::SyntaxMode::change_to('perl')",
-					php => "Kephra::Document::SyntaxMode::change_to('php')",
-					property => "Kephra::Document::SyntaxMode::change_to('property')",
-					ps => "Kephra::Document::SyntaxMode::change_to('ps')",
-					python => "Kephra::Document::SyntaxMode::change_to('python')",
-					ruby => "Kephra::Document::SyntaxMode::change_to('ruby')",
-					scheme => "Kephra::Document::SyntaxMode::change_to('scheme')",
-					sh => "Kephra::Document::SyntaxMode::change_to('sh')",
-					sql => "Kephra::Document::SyntaxMode::change_to('sql')",
-					tcl => "Kephra::Document::SyntaxMode::change_to('tcl')",
-					tex => "Kephra::Document::SyntaxMode::change_to('tex')",
-					vb => "Kephra::Document::SyntaxMode::change_to('vb')",
-					vbs => "Kephra::Document::SyntaxMode::change_to('vbs')",
-					xml => "Kephra::Document::SyntaxMode::change_to('xml')",
-					yaml => "Kephra::Document::SyntaxMode::change_to('yaml')",
+					auto => "Kephra::Document::SyntaxMode::set('auto')",
+					none => "Kephra::Document::SyntaxMode::set('none')",
+					ada => "Kephra::Document::SyntaxMode::set('ada')",
+					as => "Kephra::Document::SyntaxMode::set('as')",
+					asm => "Kephra::Document::SyntaxMode::set('asm')",
+					ave => "Kephra::Document::SyntaxMode::set('ave')",
+					baan => "Kephra::Document::SyntaxMode::set('baan')",
+					batch => "Kephra::Document::SyntaxMode::set('batch')",
+					c => "Kephra::Document::SyntaxMode::set('cpp')",
+					conf => "Kephra::Document::SyntaxMode::set('conf')",
+					context => "Kephra::Document::SyntaxMode::set('context')",
+					cs => "Kephra::Document::SyntaxMode::set('cs')",
+					css => "Kephra::Document::SyntaxMode::set('css')",
+					diff => "Kephra::Document::SyntaxMode::set('diff')",
+					eiffel => "Kephra::Document::SyntaxMode::set('eiffel')",
+					err => "Kephra::Document::SyntaxMode::set('err')",
+					forth => "Kephra::Document::SyntaxMode::set('forth')",
+					fortran => "Kephra::Document::SyntaxMode::set('fortran')",
+					html => "Kephra::Document::SyntaxMode::set('html')",
+					idl => "Kephra::Document::SyntaxMode::set('idl')",
+					java => "Kephra::Document::SyntaxMode::set('java')",
+					js => "Kephra::Document::SyntaxMode::set('js')",
+					latex => "Kephra::Document::SyntaxMode::set('latex')",
+					lisp => "Kephra::Document::SyntaxMode::set('lisp')",
+					lua => "Kephra::Document::SyntaxMode::set('lua')",
+					make => "Kephra::Document::SyntaxMode::set('make')",
+					matlab => "Kephra::Document::SyntaxMode::set('matlab')",
+					nsis => "Kephra::Document::SyntaxMode::set('nsis')",
+					pascal => "Kephra::Document::SyntaxMode::set('pascal')",
+					perl => "Kephra::Document::SyntaxMode::set('perl')",
+					php => "Kephra::Document::SyntaxMode::set('php')",
+					property => "Kephra::Document::SyntaxMode::set('property')",
+					ps => "Kephra::Document::SyntaxMode::set('ps')",
+					python => "Kephra::Document::SyntaxMode::set('python')",
+					ruby => "Kephra::Document::SyntaxMode::set('ruby')",
+					scheme => "Kephra::Document::SyntaxMode::set('scheme')",
+					sh => "Kephra::Document::SyntaxMode::set('sh')",
+					sql => "Kephra::Document::SyntaxMode::set('sql')",
+					tcl => "Kephra::Document::SyntaxMode::set('tcl')",
+					tex => "Kephra::Document::SyntaxMode::set('tex')",
+					vb => "Kephra::Document::SyntaxMode::set('vb')",
+					vbs => "Kephra::Document::SyntaxMode::set('vbs')",
+					xml => "Kephra::Document::SyntaxMode::set('xml')",
+					yaml => "Kephra::Document::SyntaxMode::set('yaml')",
 				},
 				tabs => {
-					hard => 'Kephra::Document::set_tabs_hard()',
-					soft => 'Kephra::Document::set_tabs_soft()',
-					use => 'Kephra::Document::switch_tab_mode()',
+					hard => 'Kephra::Document::Property::set_tabs_hard()',
+					soft => 'Kephra::Document::Property::set_tabs_soft()',
+					use => 'Kephra::Document::Property::switch_tab_mode()',
 					width => {
-						1 => 'Kephra::Document::set_tab_size(1)',
-						2 => 'Kephra::Document::set_tab_size(2)',
-						3 => 'Kephra::Document::set_tab_size(3)',
-						4 => 'Kephra::Document::set_tab_size(4)',
-						5 => 'Kephra::Document::set_tab_size(5)',
-						6 => 'Kephra::Document::set_tab_size(6)',
-						8 => 'Kephra::Document::set_tab_size(8)',
+						1 => 'Kephra::Document::Property::set_tab_size(1)',
+						2 => 'Kephra::Document::Property::set_tab_size(2)',
+						3 => 'Kephra::Document::Property::set_tab_size(3)',
+						4 => 'Kephra::Document::Property::set_tab_size(4)',
+						5 => 'Kephra::Document::Property::set_tab_size(5)',
+						6 => 'Kephra::Document::Property::set_tab_size(6)',
+						8 => 'Kephra::Document::Property::set_tab_size(8)',
 					},
 				},
 			},
@@ -300,18 +305,19 @@ sub get {
 					find => 'Kephra::Dialog::find()',
 					replace => 'Kephra::Dialog::replace()',
 					info => 'Kephra::Dialog::info()',
-					keymap => 'Kephra::Show::keyboard_map()',
+					keymap => 'Kephra::Help::keyboard_map()',
 				},
 				documentation => {
-					'advanced-tour' => 'Kephra::Show::advanced_tour()',
-					credits => 'Kephra::Show::credits()',
-					'feature-list' => 'Kephra::Show::feature_tour()',
-					'navigation-guide' => 'Kephra::Show::navigation_guide',
-					welcome => 'Kephra::Show::welcome()',
-					'this-version' => 'Kephra::Show::version_text()',
+					'advanced-tour' => 'Kephra::Help::advanced_tour()',
+					credits => 'Kephra::Help::credits()',
+					'feature-list' => 'Kephra::Help::feature_tour()',
+					'navigation-guide' => 'Kephra::Help::navigation_guide',
+					welcome => 'Kephra::Help::welcome()',
+					'this-version' => 'Kephra::Help::version_text()',
 				},
 				editpanel => {
 					EOL => 'Kephra::App::EditPanel::switch_EOL_visibility()',
+					'brace-light' => 'Kephra::App::EditPanel::switch_bracelight()',
 					'caret-line' => 'Kephra::App::EditPanel::switch_caret_line_visibility()',
 					font => 'Kephra::App::EditPanel::change_font()',
 					'indention-guide' => 'Kephra::App::EditPanel::switch_indention_guide_visibility()',
@@ -324,13 +330,14 @@ sub get {
 						default => "Kephra::App::ContextMenu::set_editpanel('default')",
 					},
 					margin => {
-						'text-fold' => 'Kephra::App::EditPanel::Margin::switch_fold()',
 						'line-number' => 'Kephra::App::EditPanel::Margin::switch_line_number()',
 						marker => 'Kephra::App::EditPanel::Margin::switch_marker()',
+						'text-fold' => 'Kephra::App::EditPanel::Margin::switch_fold()',
 						text => {
 							0 => 'Kephra::App::EditPanel::Margin::set_text_width(0)',
 							1 => 'Kephra::App::EditPanel::Margin::set_text_width(1)',
 							2 => 'Kephra::App::EditPanel::Margin::set_text_width(2)',
+							3 => 'Kephra::App::EditPanel::Margin::set_text_width(3)',
 							4 => 'Kephra::App::EditPanel::Margin::set_text_width(4)',
 							6 => 'Kephra::App::EditPanel::Margin::set_text_width(6)',
 							8 => 'Kephra::App::EditPanel::Margin::set_text_width(8)',
@@ -339,19 +346,21 @@ sub get {
 						},
 					},
 					'fold-toggle' => {
+						all => 'Kephra::App::EditPanel::Margin::toggle_all()',
 						here => 'Kephra::App::EditPanel::Margin::toggle_here()',
+						recursively => 'Kephra::App::EditPanel::Margin::toggle_recursively()',
 						siblings => 'Kephra::App::EditPanel::Margin::toggle_siblings()',
 					},
 				},
 				panel => {
-					notepad => 'Kephra::Extension::Notepad::switch_visibility()',
-					output => 'Kephra::Extension::Output::switch_visibility()',
+					notepad => 'Kephra::Plugin::Notepad::switch_visibility()',
+					output => 'Kephra::Plugin::Output::switch_visibility()',
 				},
 				statusbar => 'Kephra::App::StatusBar::switch_visibility()',
 				'statusbar-contexmenu' => 'Kephra::App::StatusBar::switch_contextmenu_visibility()',
 				'statusbar-info' => {
 					date => "Kephra::App::StatusBar::set_info_msg_nr(2)",
-					'length' => "Kephra::App::StatusBar::set_info_msg_nr(1)",
+					length => "Kephra::App::StatusBar::set_info_msg_nr(1)",
 					none => "Kephra::App::StatusBar::set_info_msg_nr('0')",
 				},
 				tabbar => 'Kephra::App::TabBar::switch_visibility()',
@@ -362,73 +371,77 @@ sub get {
 					search => 'Kephra::App::SearchBar::switch_visibility()',
 				},
 				'window-stay-on-top' => 'Kephra::App::Window::switch_on_top_mode()',
+				webpage => {
+					forum => 'Kephra::Help::forum_site()',
+					documentation => 'Kephra::Help::online_documentation()',
+				}
 			},
 			config => {
 				file => {
 					global => {
-						'open' => 'Kephra::Config::Global::open_current_file()',
-						'reload' => 'Kephra::Config::Global::reload_current()',
+						open => 'Kephra::Config::Global::open_current_file()',
+						reload => 'Kephra::Config::Global::reload_current()',
 						'load-from' => 'Kephra::Config::Global::load_from()',
 						'load-backup' => 'Kephra::Config::Global::load_backup_file()',
 						'load-defaults' => 'Kephra::Config::Global::load_defaults()',
-						'merge' => 'Kephra::Config::Global::merge_with()',
-						'save' => 'Kephra::Config::Global::save()',
+						merge => 'Kephra::Config::Global::merge_with()',
+						save => 'Kephra::Config::Global::save()',
 						'save-as' => 'Kephra::Config::Global::save_as()',
 					},
 					interface => {
-						commandlist => "Kephra::Show::interface_file('commandlist')",
-						menubar => "Kephra::Show::interface_file('menubar')",
-						contextmenu => "Kephra::Show::interface_file('contextmenu')",
-						toolbar => "Kephra::Show::interface_file('toolbar')",
-						maintoolbar => "Kephra::Show::interface_file('maintoolbar')",
-						searchbar => "Kephra::Show::interface_file('searchbar')",
-						statusbar => "Kephra::Show::interface_file('statusbar')",
+						commandlist => "Kephra::Config::Interface::open_file('commandlist')",
+						menubar => "Kephra::Config::Interface::open_file('menubar')",
+						contextmenu => "Kephra::Config::Interface::open_file('contextmenu')",
+						toolbar => "Kephra::Config::Interface::open_file('toolbar')",
+						maintoolbar => "Kephra::Config::Interface::open_file('maintoolbar')",
+						searchbar => "Kephra::Config::Interface::open_file('searchbar')",
+						statusbar => "Kephra::Config::Interface::open_file('statusbar')",
 					},
 					syntaxmode => {
-						ada => "Kephra::Show::syntaxmode_file('ada')",
-						as => "Kephra::Show::syntaxmode_file('as')",
-						asm => "Kephra::Show::syntaxmode_file('asm')",
-						ave => "Kephra::Show::syntaxmode_file('ave')",
-						baan => "Kephra::Show::syntaxmode_file('baan')",
-						batch => "Kephra::Show::syntaxmode_file('batch')",
-						c => "Kephra::Show::syntaxmode_file('cpp')",
-						conf => "Kephra::Show::syntaxmode_file('conf')",
-						context => "Kephra::Show::syntaxmode_file('context')",
-						cs => "Kephra::Show::syntaxmode_file('cs')",
-						css => "Kephra::Show::syntaxmode_file('css')",
-						diff => "Kephra::Show::syntaxmode_file('diff')",
-						eiffel => "Kephra::Show::syntaxmode_file('eiffel')",
-						err => "Kephra::Show::syntaxmode_file('err')",
-						forth => "Kephra::Show::syntaxmode_file('forth')",
-						fortran => "Kephra::Show::syntaxmode_file('fortran')",
-						html => "Kephra::Show::syntaxmode_file('html')",
-						idl => "Kephra::Show::syntaxmode_file('idl')",
-						java => "Kephra::Show::syntaxmode_file('java')",
-						js => "Kephra::Show::syntaxmode_file('js')",
-						latex => "Kephra::Show::syntaxmode_file('latex')",
-						lisp => "Kephra::Show::syntaxmode_file('lisp')",
-						lua => "Kephra::Show::syntaxmode_file('lua')",
-						make => "Kephra::Show::syntaxmode_file('make')",
-						matlab => "Kephra::Show::syntaxmode_file('matlab')",
-						nsis => "Kephra::Show::syntaxmode_file('nsis')",
-						pascal => "Kephra::Show::syntaxmode_file('pascal')",
-						perl => "Kephra::Show::syntaxmode_file('perl')",
-						php => "Kephra::Show::syntaxmode_file('php')",
-						property => "Kephra::Show::syntaxmode_file('property')",
-						ps => "Kephra::Show::syntaxmode_file('ps')",
-						python => "Kephra::Show::syntaxmode_file('python')",
-						ruby => "Kephra::Show::syntaxmode_file('ruby')",
-						scheme => "Kephra::Show::syntaxmode_file('scheme')",
-						sh => "Kephra::Show::syntaxmode_file('sh')",
-						sql => "Kephra::Show::syntaxmode_file('sql')",
-						tcl => "Kephra::Show::syntaxmode_file('tcl')",
-						tex => "Kephra::Show::syntaxmode_file('tex')",
-						vb => "Kephra::Show::syntaxmode_file('vb')",
-						vbs => "Kephra::Show::syntaxmode_file('vbs')",
-						xml => "Kephra::Show::syntaxmode_file('xml')",
-						yaml => "Kephra::Show::syntaxmode_file('yaml')",
+						ada => "Kephra::Document::SyntaxMode::open_file('ada')",
+						as => "Kephra::Document::SyntaxMode::open_file('as')",
+						asm => "Kephra::Document::SyntaxMode::open_file('asm')",
+						ave => "Kephra::Document::SyntaxMode::open_file('ave')",
+						baan => "Kephra::Document::SyntaxMode::open_file('baan')",
+						batch => "Kephra::Document::SyntaxMode::open_file('batch')",
+						c => "Kephra::Document::SyntaxMode::open_file('cpp')",
+						conf => "Kephra::Document::SyntaxMode::open_file('conf')",
+						context => "Kephra::Document::SyntaxMode::open_file('context')",
+						cs => "Kephra::Document::SyntaxMode::open_file('cs')",
+						css => "Kephra::Document::SyntaxMode::open_file('css')",
+						diff => "Kephra::Document::SyntaxMode::open_file('diff')",
+						eiffel => "Kephra::Document::SyntaxMode::open_file('eiffel')",
+						err => "Kephra::Document::SyntaxMode::open_file('err')",
+						forth => "Kephra::Document::SyntaxMode::open_file('forth')",
+						fortran => "Kephra::Document::SyntaxMode::open_file('fortran')",
+						html => "Kephra::Document::SyntaxMode::open_file('html')",
+						idl => "Kephra::Document::SyntaxMode::open_file('idl')",
+						java => "Kephra::Document::SyntaxMode::open_file('java')",
+						js => "Kephra::Document::SyntaxMode::open_file('js')",
+						latex => "Kephra::Document::SyntaxMode::open_file('latex')",
+						lisp => "Kephra::Document::SyntaxMode::open_file('lisp')",
+						lua => "Kephra::Document::SyntaxMode::open_file('lua')",
+						make => "Kephra::Document::SyntaxMode::open_file('make')",
+						matlab => "Kephra::Document::SyntaxMode::open_file('matlab')",
+						nsis => "Kephra::Document::SyntaxMode::open_file('nsis')",
+						pascal => "Kephra::Document::SyntaxMode::open_file('pascal')",
+						perl => "Kephra::Document::SyntaxMode::open_file('perl')",
+						php => "Kephra::Document::SyntaxMode::open_file('php')",
+						property => "Kephra::Document::SyntaxMode::open_file('property')",
+						ps => "Kephra::Document::SyntaxMode::open_file('ps')",
+						python => "Kephra::Document::SyntaxMode::open_file('python')",
+						ruby => "Kephra::Document::SyntaxMode::open_file('ruby')",
+						scheme => "Kephra::Document::SyntaxMode::open_file('scheme')",
+						sh => "Kephra::Document::SyntaxMode::open_file('sh')",
+						sql => "Kephra::Document::SyntaxMode::open_file('sql')",
+						tcl => "Kephra::Document::SyntaxMode::open_file('tcl')",
+						tex => "Kephra::Document::SyntaxMode::open_file('tex')",
+						vb => "Kephra::Document::SyntaxMode::open_file('vb')",
+						vbs => "Kephra::Document::SyntaxMode::open_file('vbs')",
+						xml => "Kephra::Document::SyntaxMode::open_file('xml')",
+						yaml => "Kephra::Document::SyntaxMode::open_file('yaml')",
 					},
-					templates => 'Kephra::Show::templates_file()',
+					templates => 'Kephra::Config::Global::open_templates_file()',
 				},
 			},
 		},
@@ -445,7 +458,7 @@ sub get {
 					'redo-several' => 'Kephra::Edit::History::can_redo()',
 					'goto-begin' => 'Kephra::Edit::History::can_undo()',
 					'goto-end' => 'Kephra::Edit::History::can_redo()',
-					'delete' => 'Kephra::Edit::History::can_undo() or Kephra::Edit::History::can_redo()',
+					delete => 'Kephra::Edit::History::can_undo() or Kephra::Edit::History::can_redo()',
 				},
 				cut => 'Kephra::Edit::can_copy()',
 				copy => 'Kephra::Edit::can_copy()',
@@ -468,7 +481,7 @@ sub get {
 				prev => 'Kephra::Edit::Search::item_findable()',
 				next => 'Kephra::Edit::Search::item_findable()',
 				first => 'Kephra::Edit::Search::item_findable()',
-				'last' => 'Kephra::Edit::Search::item_findable()',
+				last => 'Kephra::Edit::Search::item_findable()',
 				selection => 'Kephra::Edit::can_copy()',
 			},
 			replace => {
@@ -478,9 +491,9 @@ sub get {
 				'with-confirm' => 'Kephra::Edit::Search::_exist_find_item()',
 				selection => 'Kephra::Edit::can_copy()',
 			},
-			tool => {
-				'run-document' => '! Kephra::Extension::Output::is_running()',
-				'stop-document' => 'Kephra::Extension::Output::is_running()',
+			'tool-interpreter' => {
+				'run-document' => '! Kephra::Plugin::Output::is_running()',
+				'stop-document' => 'Kephra::Plugin::Output::is_running()',
 			},
 		},
 		enable_event => {
@@ -511,9 +524,9 @@ sub get {
 				'with-confirm' => 'find.item.changed',
 				selection => 'document.text.select',
 			},
-			tool => {
-				'run-document' => 'extension.output.run',
-				'stop-document' => 'extension.output.run',
+			'tool-interpreter' => {
+				'run-document' => 'plugin.output.run',
+				'stop-document' => 'plugin.output.run',
 			},
 		},
 		state => {
@@ -549,18 +562,17 @@ sub get {
 				},
 			},
 			document => {
-				'auto-indention' => 'Kephra::Document::get_autoindention()',
-				'brace-light' => 'Kephra::Document::get_bracelight()',
-				'brace-indention' => 'Kephra::Document::get_braceindention()',
+				'auto-indention' => 'Kephra::Document::Property::get_autoindention()',
+				'brace-indention' => 'Kephra::Document::Property::get_braceindention()',
 				EOL => {
-					'cr+lf' => "Kephra::Document::get_EOL_mode() eq 'cr+lf'",
-					'cr' => "Kephra::Document::get_EOL_mode() eq 'cr'",
-					'lf' => "Kephra::Document::get_EOL_mode() eq 'lf'",
+					'cr+lf' => "Kephra::Document::Property::get_EOL_mode() eq 'cr+lf'",
+					cr => "Kephra::Document::Property::get_EOL_mode() eq 'cr'",
+					lf => "Kephra::Document::Property::get_EOL_mode() eq 'lf'",
 				},
 				readonly => {
-					'as-attr' => "Kephra::Document::get_readonly() eq 'protect';",
-					on => "Kephra::Document::get_readonly() eq 'on';",
-					off => "Kephra::Document::get_readonly() eq 'off';",
+					'as-attr' => "Kephra::Document::Property::get_readonly() eq 'protect';",
+					on => "Kephra::Document::Property::get_readonly() eq 'on';",
+					off => "Kephra::Document::Property::get_readonly() eq 'off';",
 				},
 				syntaxmode => {
 					none => "Kephra::Document::SyntaxMode::_ID() eq 'none';",
@@ -608,23 +620,24 @@ sub get {
 					yaml => "Kephra::Document::SyntaxMode::_ID() eq 'yaml';",
 				},
 				tabs => {
-					soft => 'Kephra::Document::get_tab_mode() == 0',
-					hard => 'Kephra::Document::get_tab_mode() == 1',
-					use => 'Kephra::Document::get_tab_mode()',
+					soft => 'Kephra::Document::Property::get_tab_mode() == 0',
+					hard => 'Kephra::Document::Property::get_tab_mode() == 1',
+					use => 'Kephra::Document::Property::get_tab_mode()',
 					width => {
-						1 => 'Kephra::Document::get_tab_size() == 1',
-						2 => 'Kephra::Document::get_tab_size() == 2',
-						3 => 'Kephra::Document::get_tab_size() == 3',
-						4 => 'Kephra::Document::get_tab_size() == 4',
-						5 => 'Kephra::Document::get_tab_size() == 5',
-						6 => 'Kephra::Document::get_tab_size() == 6',
-						8 => 'Kephra::Document::get_tab_size() == 8',
+						1 => 'Kephra::Document::Property::get_tab_size() == 1',
+						2 => 'Kephra::Document::Property::get_tab_size() == 2',
+						3 => 'Kephra::Document::Property::get_tab_size() == 3',
+						4 => 'Kephra::Document::Property::get_tab_size() == 4',
+						5 => 'Kephra::Document::Property::get_tab_size() == 5',
+						6 => 'Kephra::Document::Property::get_tab_size() == 6',
+						8 => 'Kephra::Document::Property::get_tab_size() == 8',
 					},
 				},
 			},
 			view => {
 				editpanel => {
 					EOL => 'Kephra::App::EditPanel::EOL_visible();',
+					'brace-light' => 'Kephra::App::EditPanel::bracelight_visible()',
 					'caret-line' => 'Kephra::App::EditPanel::caret_line_visible()',
 					'indention-guide' => 'Kephra::App::EditPanel::indention_guide_visible()',
 					'line-wrap' => 'Kephra::App::EditPanel::get_autowrap_mode()',
@@ -632,7 +645,7 @@ sub get {
 					whitespace => 'Kephra::App::EditPanel::whitespace_visible()',
 					contextmenu => {
 						custom => "Kephra::App::ContextMenu::get_editpanel() eq 'custom';",
-						'no' => "Kephra::App::ContextMenu::get_editpanel() eq 'none';",
+						no => "Kephra::App::ContextMenu::get_editpanel() eq 'none';",
 						default => "Kephra::App::ContextMenu::get_editpanel() eq 'default';",
 					},
 					margin => {
@@ -643,6 +656,7 @@ sub get {
 							0 => 'Kephra::App::EditPanel::Margin::get_text_width() == 0',
 							1 => 'Kephra::App::EditPanel::Margin::get_text_width() == 1',
 							2 => 'Kephra::App::EditPanel::Margin::get_text_width() == 2',
+							3 => 'Kephra::App::EditPanel::Margin::get_text_width() == 3',
 							4 => 'Kephra::App::EditPanel::Margin::get_text_width() == 4',
 							6 => 'Kephra::App::EditPanel::Margin::get_text_width() == 6',
 							8 => 'Kephra::App::EditPanel::Margin::get_text_width() == 8',
@@ -652,8 +666,8 @@ sub get {
 					},
 				},
 				panel => {
-					notepad => 'Kephra::Extension::Notepad::get_visibility()',
-					output => 'Kephra::Extension::Output::get_visibility()',
+					notepad => 'Kephra::Plugin::Notepad::get_visibility()',
+					output => 'Kephra::Plugin::Output::get_visibility()',
 				},
 				statusbar => 'Kephra::App::StatusBar::get_visibility()',
 				'statusbar-contexmenu' => 'Kephra::App::StatusBar::get_contextmenu_visibility()',
@@ -679,7 +693,7 @@ sub get {
 			'app-exit' => 'app-exit.xpm',
 			file => {
 				new => 'file-new.xpm',
-				'open' => 'file-open.xpm',
+				open => 'file-open.xpm',
 				'save-current' => 'file-save.xpm',
 				'save-all' => 'file-save-all.xpm',
 				print => 'file-print.xpm',
@@ -859,8 +873,9 @@ sub get {
 			},
 			tool => {
 				note => 'f4',
-				'run-document' => 'f5',
-				'stop-document' => 'shift+f5',
+				note-selection => 'shift+f4',
+				'interpreter-run-document' => 'f5',
+				'interpreter-stop-document' => 'shift+f5',
 			},
 			document => {
 				change => {
@@ -885,9 +900,11 @@ sub get {
 					keymap => 'alt+shift+k',
 				},
 				'editpanel-fold-toggle' => {
-					'here' => 'alt+plus',
-					'siblings' => 'alt+shift+plus',
-				}
+					all => 'alt+shift+plus',
+					here => 'alt+minus',
+					recursively => 'alt+shift+minus',
+					siblings => 'alt+plus',
+				},
 				'panel-notepad' => 'ctrl+f4',
 				'panel-output' => 'ctrl+f5',
 				'window-stay-on-top' => 'ctrl+t',
