@@ -11,9 +11,9 @@ sub get {
 			{'menu file_open' => [
 				'item file-open',
 				'item file-open-dir',
-				'',
+				undef ,
 				'item file-insert',
-				'',
+				undef ,
 				'item file-reload',
 				'item file-reload-all',
 			],},
@@ -21,26 +21,26 @@ sub get {
 				'item file-close-current',
 				'item file-close-other',
 				'item file-close-all',
-				'',
+				undef ,
 				'item file-close-unsaved',
 				'item file-close-other-unsaved',
 				'item file-close-all-unsaved',
 			],},
-			'',
+			undef ,
 			'menu file_history',
 			'menu file_insert_templates',
 			{'menu file_session' => [
 				'item file-session-open',
 				'item file-session-add',
 				'item file-session-save',
-				'',
+				undef ,
 				'item file-session-backup-open',
 				'item file-session-backup-save',
-				'',
+				undef ,
 				'item file-session-import',
 				'item file-session-export',
 			],},
-			'',
+			undef ,
 			'item file-save-current',
 			#'menu file_save' => []
 			'item file-save-all',
@@ -48,7 +48,7 @@ sub get {
 			'item file-save-copy-as',
 			'item file-rename',
 			#'item file-print',
-			'',
+			undef ,
 			'item app-exit-unsaved',
 			'item app-exit',
 		],},
@@ -58,19 +58,19 @@ sub get {
 			{'menu edit_changes' => [
 				'item edit-changes-undo-several',
 				'item edit-changes-redo-several',
-				'',
+				undef ,
 				'item edit-changes-goto-begin',
 				'item edit-changes-goto-end',
-				'',
+				undef ,
 				'item edit-changes-delete',
 			],},
-			'',
+			undef ,
 			'item edit-cut',
 			'item edit-copy',
 			'item edit-paste',
 			'item edit-replace',
 			'item edit-delete',
-			'',
+			undef ,
 			'item select-document',
 			{'menu selection' => [
 				'item edit-selection-move-char-left',
@@ -89,38 +89,38 @@ sub get {
 				'item edit-line-delete',
 				'item edit-line-delete-left',
 				'item edit-line-delete-right',
-				'',
+				undef ,
 				'item edit-line-move-line-up',
 				'item edit-line-move-line-down',
 				'item edit-line-move-page-up',
 				'item edit-line-move-page-down',
 			],},
 			#'menu navigation' => [,
-			'',
+			undef ,
 			{'menu selection_format' => [
 				'item edit-selection-format-indent-char',
 				'item edit-selection-format-dedent-char',
 				'item edit-selection-format-indent-tab',
 				'item edit-selection-format-dedent-tab',
 				'item edit-selection-format-align-on-begin',
-				'',
+				undef ,
 				'item edit-selection-format-join-lines',
-				'',
+				undef ,
 				'item edit-selection-format-block-on-right-margin',
 				'item edit-selection-format-block-on-width',
 				'item edit-selection-format-linewrap-on-right-margin',
 				'item edit-selection-format-linewrap-on-width',
-				'',
+				undef ,
 				'item edit-selection-format-del-trailing-whitespace',
 			],},
 			{'menu selection_comment' => [
 				'item edit-selection-comment-add-perl',
 				'item edit-selection-comment-del-perl',
 				'item edit-selection-comment-toggle-perl',
-				'',
+				undef ,
 				'item edit-selection-comment-add-c',
 				'item edit-selection-comment-del-c',
-				'',
+				undef ,
 				'item edit-selection-comment-add-xml',
 				'item edit-selection-comment-del-xml',
 			],},
@@ -129,9 +129,14 @@ sub get {
 				'item edit-selection-convert-lowercase',
 				'item edit-selection-convert-titlecase',
 				'item edit-selection-convert-sentencecase',
-				'',
+				undef ,
 				'item edit-selection-convert-spaces2tabs',
 				'item edit-selection-convert-tabs2spaces',
+				undef ,
+				'item edit-selection-convert-spaces2entities',
+				'item edit-selection-convert-entities2spaces',
+				'item edit-selection-convert-chars2entities',
+				'item edit-selection-convert-entities2chars',
 			],},
 		],},
 		{'menu search' => [
@@ -155,20 +160,20 @@ sub get {
 			{'menu search_attributes' => [
 				'checkitem search-attribute-incremental-switch',
 				'checkitem search-attribute-autowrap-switch',
-				'',
+				undef ,
 				'checkitem search-attribute-regex-switch',
 				'checkitem search-attribute-match-whole-word-switch',
 				'checkitem search-attribute-match-word-begin-switch',
 				'checkitem search-attribute-match-case-switch',
-				'',
+				undef ,
 				'radioitem search-range-selection',
 				'radioitem search-range-document',
 				'radioitem search-range-open-docs',
 			],},
-			'',
+			undef ,
 			'item goto-line',
 			'item goto-last-edit',
-			'',
+			undef ,
 			{'menu bookmark_goto' => [
 				'item bookmark-goto-1',
 				'item bookmark-goto-2',
@@ -197,24 +202,27 @@ sub get {
 		],},
 		{'menu tools' => [
 			'item tool-note',
-			'',
-			'item tool-run-document',
-			'item tool-stop-document',
+			'item tool-note-selection',
+			undef ,
+			'item tool-interpreter-run-document',
+			'item tool-interpreter-stop-document',
+			undef ,
+			'item tool-output-inc',
 		],},
 		{'menu document' => [
 			{'menu document_change' => [
 				'item document-change-prev',
 				'item document-change-next',
 				'item document-change-back',
-				'',
+				undef ,
 				'item document-move-left',
 				'item document-move-right',
 			],},
-			'',
+			undef ,
 			{'menu document_syntaxmode' => [
 				'item document-syntaxmode-auto',
 				'checkitem document-syntaxmode-none',
-				'',
+				undef ,
 				{'menu document_syntaxmode_A-M' => [
 					'checkitem document-syntaxmode-ada',
 					'checkitem document-syntaxmode-as',
@@ -261,7 +269,7 @@ sub get {
 					'checkitem document-syntaxmode-xml',
 					'checkitem document-syntaxmode-yaml',
 				],},
-				'',
+				undef ,
 				{'menu document_syntaxmode_compiled' => [
 					'checkitem document-syntaxmode-asm',
 					'checkitem document-syntaxmode-c',
@@ -322,7 +330,6 @@ sub get {
 					'checkitem document-syntaxmode-matlab',
 				],},
 			],},
-			'checkitem document-brace-light',
 			'checkitem document-brace-indention',
 			'checkitem document-auto-indention',
 			'checkitem document-tabs-use',
@@ -348,7 +355,11 @@ sub get {
 		],},
 		{'menu view' => [
 			'checkitem view-window-stay-on-top',
-			'',
+			undef,
+			{'menu view_panel' => [
+				'checkitem view-panel-notepad',
+				'checkitem view-panel-output',
+			],},
 			{'menu view_contextmenu' => [
 				'checkitem view-tabbar-contexmenu',
 				{'menu view_editpanel_contexmenu' => [
@@ -360,27 +371,34 @@ sub get {
 			],},
 			{'menu view_bars' => [
 				'checkitem view-toolbar-main',
-				'checkitem view-tabbar',
 				'checkitem view-toolbar-search',
 				'checkitem view-statusbar',
-			],},            
-			'',
+			],},
+			undef ,
 			'checkitem view-editpanel-margin-marker',
 			'checkitem view-editpanel-margin-line-number',
 			'checkitem view-editpanel-margin-text-fold',
+			{'menu view_text_fold' => [
+				'item view-editpanel-fold-toggle-here',
+				'item view-editpanel-fold-toggle-recursively',
+				'item view-editpanel-fold-toggle-siblings',
+				'item view-editpanel-fold-toggle-all',
+			],},
 			{'menu view_textmargin' => [
 				'radioitem view-editpanel-margin-text-0',
 				'radioitem view-editpanel-margin-text-1',
 				'radioitem view-editpanel-margin-text-2',
+				'radioitem view-editpanel-margin-text-3',
 				'radioitem view-editpanel-margin-text-4',
 				'radioitem view-editpanel-margin-text-6',
 				'radioitem view-editpanel-margin-text-8',
 				'radioitem view-editpanel-margin-text-10',
 				'radioitem view-editpanel-margin-text-12',
 			],},
-			'',
+			undef ,
 			'checkitem view-editpanel-right-margin',
 			'checkitem view-editpanel-indention-guide',
+			'checkitem view-editpanel-brace-light',
 			'checkitem view-editpanel-caret-line',
 			'checkitem view-editpanel-line-wrap',
 			'checkitem view-editpanel-EOL',
@@ -389,18 +407,18 @@ sub get {
 		],},
 		{'menu config' => [
 			'item view-dialog-config',
-			'',
+			undef ,
 			'menu config_app_lang',
-			'',
+			undef ,
 			{'menu config_global' => [
 				'item config-file-global-open',
 				'item config-file-global-reload',
 				'item config-file-global-save',
-				'',
+				undef ,
 				'item config-file-global-load-from',
 				'item config-file-global-merge',
 				'item config-file-global-save-as',
-				'',
+				undef ,
 				'item config-file-global-load-backup',
 				'item config-file-global-load-defaults',
 			],},
@@ -469,7 +487,10 @@ sub get {
 			'item view-documentation-feature-list',
 			'item view-documentation-advanced-tour',
 			'item view-documentation-credits',
-			'',
+			undef ,
+			'item view-webpage-documentation',
+			'item view-webpage-forum',
+			undef ,
 			'item view-dialog-keymap',
 			'item view-dialog-info',
 		],},
